==> plugin_codelab_new-0.0.1.tar.gz: lib/pages/likes_and_dislikes.dart <==
// import 'package:feed_app/widgets/loadingButtonIndicator.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_screenutil/screen_util.dart';
import 'package:plugin_codelab_new/bloc/feed_cubit.dart';
import 'package:plugin_codelab_new/models/report_model.dart';
import 'package:plugin_codelab_new/models/user_model.dart';
// import 'package:flutter_screenutil/screenutil.dart';
// import 'package:image_editor_pro/image_editor_pro.dart';
import 'package:timeago/timeago.dart' as timeago;

final lastDate = new DateTime(
  DateTime.now().year - 10,
  DateTime.now().month,
);

String selectedValue = lastDate.toString();

class LikesAndDislikes extends StatefulWidget {
  const LikesAndDislikes(
      {Key key,
      @required this.likesList,
      @required this.dislikesList,
      @required this.postTitle})
      : super(key: key);

  final List<ReportModel> likesList;
  final List<ReportModel> dislikesList;
  final String postTitle;
  @override
  _LikesAndDislikesState createState() => _LikesAndDislikesState();
}

class _LikesAndDislikesState extends State<LikesAndDislikes> {
  FeedCubit feedCubit;

  @override
  void initState() {
    feedCubit = BlocProvider.of<FeedCubit>(context);
    super.initState();
  }

  // Future<UserModel> getUserById(id) async {
  //   UserModel user = await feedCubit.feedRepository.fetchUserData(id);
  //   return user;
  // }

  _buildList(listToShow, type) {
    return listToShow.length > 0
        ? ListView.builder(
            padding: const EdgeInsets.all(8),
            itemCount: listToShow.length,
            itemBuilder: (BuildContext context, int index) {
              UserModel userData = listToShow[index].user;
              final date = DateTime.now();
              final difference =
                  date.difference(listToShow[index].createdAt).inMinutes;
              final fifteenAgo = new DateTime.now()
                  .subtract(new Duration(minutes: difference));
              return Container(
                  // //  padding: EdgeInsets.all(ScreenUtil().setWidth(20)),
                  height: ScreenUtil().setHeight(50),
                  //   margin: EdgeInsets.only(
                  //     bottom: ScreenUtil().setWidth(8.0),
                  //   ),
                  // color: Color(0xffE8ECEF),
                  // decoration: BoxDecoration(
                  //     border: Border(
                  //   bottom: BorderSide(width: 4, color: Colors.white),
                  // )),
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: [
                      Container(
                          margin:
                              EdgeInsets.only(top: ScreenUtil().setWidth(15)),
                          height: 200,
                          child: Stack(children: <Widget>[
                            ClipOval(
                              child: Image.network(
                                userData.profileImg,
                                width: ScreenUtil().setWidth(36),
                                height: ScreenUtil().setHeight(26),
                                fit: BoxFit.cover,
                              ),
                            ),
                            Row(
                              children: [
                                // Padding(
                                //   //  padding: EdgeInsets.only(top:ScreenUtil().setHeight(5),left:ScreenUtil().setHeight(40)),
                                //   padding: EdgeInsets.symmetric(
                                //       horizontal: ScreenUtil().setWidth(
                                //     25,
                                //   )
                                //   ),
                                // ,
                                // vertical: ScreenUtil().setHeight(7)),
                                Container(
                                  width: ScreenUtil().setWidth(25),
                                  height: ScreenUtil().setHeight(25),
                                  alignment: Alignment.bottomRight,
                                  margin: EdgeInsets.only(
                                      left: ScreenUtil().setWidth(12),
                                      top: ScreenUtil().setWidth(5)),
                                  child: ClipOval(
                                      child: Container(
                                    color: type == "Likes"
                                        ? Colors.green
                                        : Colors.red,
                                    child: SizedBox(
                                        width: 15,
                                        height: 15,
                                        child: Icon(
                                          type == "Likes"
                                              ? Icons.thumb_up_off_alt
                                              : Icons.thumb_down_off_alt,
                                          size: 13,
                                          color: Colors.black.withOpacity(0.5),
                                        )),
                                  )),
                                ),
                                // ),
                              ],
                            ),
                          ])),
                      Container(
                        // width: ScreenUtil().setWidth(50),
                        // height: ScreenUtil().setHeight(50),
                        margin: EdgeInsets.only(
                            top: ScreenUtil().setWidth(15),
                            left: ScreenUtil().setWidth(15)),
                        child: Column(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              Row(children: [
                                Text(
                                    userData.firstName.toString() +
                                        " " +
                                        userData.lastName.toString(),
                                    style:
                                        TextStyle(fontWeight: FontWeight.bold)),
                                Container(
                                  margin: EdgeInsets.only(
                                      left: ScreenUtil().setWidth(100)),
                                  child: Text(
                                    timeago.format(fifteenAgo,
                                        locale: 'en_short'),
                                    style: TextStyle(
                                      color: Color(0xFF98A9BC),
                                      fontWeight: FontWeight.bold,
                                    ),
                                  ),
                                )
                              ]),
                              Text(
                                userData.about,
                                style: TextStyle(
                                  color: Color(0xFF98A9BC),
                                  height: 2,
                                ),
                              ),
                              // ),
                            ]),
                      ),
                      // Container(
                      //     height: ScreenUtil().setHeight(60),
                      //     // width: ScreenUtil().setWidth(150),
                      //     child: Text(
                      //         timeago.format(fifteenAgo, locale: 'en_short'),
                      //         style: TextStyle(
                      //             fontWeight: FontWeight.bold,
                      //             color: Color(0xFF98A9BC)))),
                    ],
                  ));
            })
        : Padding(
            padding: const EdgeInsets.all(50),
            child: Container(
              child: Text(
                "No " + type + " yet...",
                textAlign: TextAlign.center,
                style: TextStyle(
                    fontSize: ScreenUtil().setWidth(20),
                    color: Color(0xFF98A9BC)),
              ),
            ),
          );
  }

  TabBar get _tabBar => TabBar(
        labelColor: Color(0xFF083356),
        unselectedLabelColor: Color(0xFF083356),
        indicatorColor: Color(0xFFE083356),
        indicatorWeight: 5,
        tabs: [
          Tab(
              child: Text(
                  "Likes" + "(" + this.widget.likesList.length.toString() + ")",
                  style: TextStyle(
                    color: Color(0xFF083356),
                    fontWeight: FontWeight.bold,
                    fontSize: ScreenUtil().setWidth(15),
                  ))),
          Tab(
            child: Text(
                "Dislikes" +
                    "(" +
                    this.widget.dislikesList.length.toString() +
                    ")",
                style: TextStyle(
                  color: Color(0xFF083356),
                  fontWeight: FontWeight.bold,
                  fontSize: ScreenUtil().setWidth(15),
                )),
          ),
          //  Tab(
          // child: Text(
          //   "Present",
          //   style: TextStyle(fontFamily: "BarlowBold", color: black),
          // ),
        ],
      );
  // @override
  // Widget build(BuildContext context) {
  //   return DefaultTabController(
  //     length: 2,
  //     child: Scaffold(
  //       appBar: AppBar(
  //         backgroundColor: Color(0xFF083356),
  //         title: Text('AppBar'),
  //         bottom: PreferredSize(
  //           preferredSize: _tabBar.preferredSize,
  //           child: ColoredBox(
  //             color: Colors.white,
  //             child: _tabBar,
  //           ),
  //         ),
  //       ),
  //     ),
  //   );
  // }

  @override
  Widget build(BuildContext context) {
    return DefaultTabController(
      length: 2,
      child: Scaffold(
        appBar: AppBar(
          backgroundColor: Color(0xFF083356),
          title: Text(
            this.widget.postTitle,
            style: TextStyle(color: Colors.white),
          ),
          bottom: PreferredSize(
            preferredSize: _tabBar.preferredSize,
            child: ColoredBox(
              color: Colors.white,
              child: _tabBar,
            ),
          ),
          leading: GestureDetector(
            child: Icon(Icons.arrow_back, color: Colors.white),
            onTap: () {
              Navigator.pop(context);
            },
            // child: ColoredBox(
            //   color: Colors.white,
            //   child: _tabBar,
            // ),
            //  child: Icon(Icons.arrow_back, color: Colors.white)),

            // bottom: TabBar(
            //   labelColor: Colors.red,
            //   //labelColor: Color(0xFF083356),
            //   unselectedLabelColor: Colors.red,
            //   //unselectedLabelColor: Color(0xFF083356),
            //   indicatorColor: Color(0xFF083356),
            //   tabs: [
            //     Tab(text: "Likes", icon: Icon(Icons.thumb_up_off_alt)),
            //     Tab(text: "Disikes", icon: Icon(Icons.thumb_down_off_alt)),
            //   ],
            // ),
          ),
        ),
        body: TabBarView(
          children: [
            _buildList(this.widget.likesList, "Likes"),
            _buildList(this.widget.dislikesList, "Disikes"),
          ],
        ),
      ),
    );
  }
}

==> plugin_codelab_new-0.0.2.tar.gz: lib/pages/likes_and_dislikes.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_screenutil/screen_util.dart';
import 'package:plugin_codelab_new/bloc/feed_cubit.dart';
import 'package:plugin_codelab_new/models/report_model.dart';
import 'package:plugin_codelab_new/models/user_model.dart';
import 'package:timeago/timeago.dart' as timeago;

final lastDate = new DateTime(
  DateTime.now().year - 10,
  DateTime.now().month,
);

String selectedValue = lastDate.toString();

class LikesAndDislikes extends StatefulWidget {
  const LikesAndDislikes(
      {Key key,
      @required this.likesList,
      @required this.dislikesList,
      @required this.postTitle})
      : super(key: key);

  final List<ReportModel> likesList;
  final List<ReportModel> dislikesList;
  final String postTitle;
  @override
  _LikesAndDislikesState createState() => _LikesAndDislikesState();
}

class _LikesAndDislikesState extends State<LikesAndDislikes> {
  FeedCubit feedCubit;

  @override
  void initState() {
    feedCubit = BlocProvider.of<FeedCubit>(context);
    super.initState();
  }

  _buildList(listToShow, type) {
    return listToShow.length > 0
        ? ListView.builder(
            padding: const EdgeInsets.all(8),
            itemCount: listToShow.length,
            itemBuilder: (BuildContext context, int index) {
              UserModel userData = listToShow[index].user;
              final date = DateTime.now();
              final difference =
                  date.difference(listToShow[index].createdAt).inMinutes;
              final fifteenAgo = new DateTime.now()
                  .subtract(new Duration(minutes: difference));
              return Container(
                  height: ScreenUtil().setHeight(50),
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: [
                      Container(
                          margin:
                              EdgeInsets.only(top: ScreenUtil().setWidth(15)),
                          height: ScreenUtil().setWidth(200),
                          width: ScreenUtil().setWidth(60),
                          child: Stack(children: <Widget>[
                            ClipOval(
                              child: Image.network(
                                userData.profileImg,
                                width: ScreenUtil().setWidth(36),
                                height: ScreenUtil().setHeight(26),
                                fit: BoxFit.cover,
                              ),
                            ),
                            Row(
                              children: [
                                Container(
                                  width: ScreenUtil().setWidth(25),
                                  height: ScreenUtil().setHeight(25),
                                  alignment: Alignment.bottomRight,
                                  margin: EdgeInsets.only(
                                      left: ScreenUtil().setWidth(12),
                                      top: ScreenUtil().setWidth(5)),
                                  child: ClipOval(
                                      child: Container(
                                    color: type == "Likes"
                                        ? Colors.green
                                        : Colors.red,
                                    child: SizedBox(
                                        width: 15,
                                        height: 15,
                                        child: Icon(
                                          type == "Likes"
                                              ? Icons.thumb_up_off_alt
                                              : Icons.thumb_down_off_alt,
                                          size: 13,
                                          color: Colors.black.withOpacity(0.5),
                                        )),
                                  )),
                                ),
                              ],
                            ),
                          ])),
                      Container(
                        child: Column(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              Row(children: [
                                Container(
                                  width: ScreenUtil().setWidth(220),
                                  margin: EdgeInsets.only(
                                      top: ScreenUtil().setWidth(15)),
                                  child: Text(
                                      userData.firstName.toString() +
                                          " " +
                                          userData.lastName.toString(),
                                      style: TextStyle(
                                          fontWeight: FontWeight.bold)),
                                ),
                                Container(
                                  margin: EdgeInsets.only(
                                      top: ScreenUtil().setWidth(15)),
                                  child: Text(
                                    timeago.format(fifteenAgo,
                                        locale: 'en_short'),
                                    style: TextStyle(
                                      color: Color(0xFF98A9BC),
                                      fontWeight: FontWeight.bold,
                                    ),
                                  ),
                                )
                              ]),
                              Text(
                                userData.about,
                                style: TextStyle(
                                  color: Color(0xFF98A9BC),
                                  height: 2,
                                ),
                              ),
                            ]),
                      ),
                    ],
                  ));
            })
        : Padding(
            padding: const EdgeInsets.all(50),
            child: Container(
              child: Text(
                "No " + type + " yet...",
                textAlign: TextAlign.center,
                style: TextStyle(
                    fontSize: ScreenUtil().setWidth(20),
                    color: Color(0xFF98A9BC)),
              ),
            ),
          );
  }

  TabBar get _tabBar => TabBar(
        labelColor: Color(0xFF083356),
        unselectedLabelColor: Color(0xFF083356),
        indicatorColor: Color(0xFFE083356),
        indicatorWeight: 5,
        labelStyle: TextStyle(
            fontWeight: FontWeight.bold, fontSize: ScreenUtil().setWidth(15)),
        unselectedLabelStyle: TextStyle(
            fontWeight: FontWeight.normal, fontSize: ScreenUtil().setWidth(15)),
        tabs: [
          Tab(
              child: Text(
            "Likes" + "(" + this.widget.likesList.length.toString() + ")",
          )),
          Tab(
            child: Text(
              "Dislikes" +
                  "(" +
                  this.widget.dislikesList.length.toString() +
                  ")",
            ),
          ),
        ],
      );

  @override
  Widget build(BuildContext context) {
    return DefaultTabController(
      length: 2,
      child: Padding(
        padding: EdgeInsets.only(top: ScreenUtil().setHeight(20)),
        child: Scaffold(
          appBar: AppBar(
            backgroundColor: Color(0xFF083356),
            title: Container(
              height: ScreenUtil().setHeight(20),
              child: Text(
                this.widget.postTitle,
                style: TextStyle(color: Colors.white),
              ),
            ),
            bottom: PreferredSize(
              preferredSize: _tabBar.preferredSize,
              child: Container(
                height: 80,
                child: ColoredBox(
                  color: Colors.white,
                  child: _tabBar,
                ),
              ),
            ),
            leading: GestureDetector(
              child: Icon(Icons.arrow_back, color: Colors.white),
              onTap: () {
                Navigator.pop(context);
              },
            ),
          ),
          body: TabBarView(
            children: [
              _buildList(this.widget.likesList, "Likes"),
              _buildList(this.widget.dislikesList, "Disikes"),
            ],
          ),
        ),
      ),
    );
  }
}
